@@ -9,8 +9,8 @@ from os_file_handler import file_handler as fh
 
 
 # will return a dictionary containing all of the strings in the xml file by "id": "value"
-def build_strings_dict(project_path):
-    strings_xml = xh.read_xml_file(os.path.join(project_path, 'app', 'src', 'main', 'res', 'values', 'strings.xml'))
+def build_strings_dict(strings_file_path):
+    strings_xml = xh.read_xml_file(strings_file_path)
     strings_node = xh.find_all_nodes(xh.get_root_node(strings_xml), 'string')
 
     nodes_to_translate = []
@@ -22,11 +22,10 @@ def build_strings_dict(project_path):
 
 
 # will turn the strings dictionary to a good looking xlsx file
-def dict_to_xlsx(project_path, string_nodes, output_path, src_language, languages_arr):
+def dict_to_xlsx(string_nodes, output_path, src_language, languages_arr):
     import xlsxwriter
 
     # Create an new Excel file and add a worksheet.
-    project_name = fh.get_dir_name(project_path)
     workbook = xlsxwriter.Workbook(output_path)
 
     big_red_format = workbook.add_format()
