@@ -7,6 +7,6 @@ import os_android_strings_extractor.modules.strings_extractor_boilerplate as bp
 # languages                                                                        #
 ####################################################################################
 
-def extract_to_xlsx(project_path, output_path, src_language, languages_list):
-    strings_dict = bp.build_strings_dict(project_path)
-    bp.dict_to_xlsx(project_path, strings_dict, output_path, src_language, languages_list)
+def extract_to_xlsx(strings_file_path, output_path, src_language, languages_list):
+    strings_dict = bp.build_strings_dict(strings_file_path)
+    bp.dict_to_xlsx(strings_dict, output_path, src_language, languages_list)
